@@ -6,19 +6,20 @@ const Gio = imports.gi.Gio;
 const Lang = imports.lang;
 const Main = imports.ui.main;
 
-const SETTINGS_SCHEMA = 'org.gnome.shell.extensions.user-theme';
 const SETTINGS_KEY = 'name';
 
-function ThemeManager() {
-    this._init();
-}
+const ExtensionUtils = imports.misc.extensionUtils;
+const Me = ExtensionUtils.getCurrentExtension();
+const Convenience = Me.imports.convenience;
+
+const ThemeManager = new Lang.Class({
+    Name: 'UserTheme.ThemeManager',
 
-ThemeManager.prototype = {
     _init: function() {
+        this._settings = Convenience.getSettings();
     },
 
     enable: function() {
-        this._settings = new Gio.Settings({ schema: SETTINGS_SCHEMA });
         this._changedId = this._settings.connect('changed::'+SETTINGS_KEY, Lang.bind(this, this._changeTheme));
         this._changeTheme();
     },
@@ -29,8 +30,6 @@ ThemeManager.prototype = {
             this._changedId = 0;
         }
 
-        this._settings = null;
-
         Main.setThemeStylesheet(null);
         Main.loadTheme();
     },
@@ -64,9 +63,8 @@ ThemeManager.prototype = {
         Main.setThemeStylesheet(_stylesheet);
         Main.loadTheme();
     }
-}
+});
 
-
-function init(metadata) {
+function init() {
     return new ThemeManager();
 }
